@@ -76,8 +76,6 @@
 #include <string.h>
 #include <assert.h>
 #include <ctype.h>
-#include <inttypes.h>
-#include <stdbool.h>
 #include <limits.h>
 
 #include "jasper/jas_math.h"
@@ -464,6 +462,7 @@ int jas_image_encode(jas_image_t *image, jas_stream_t *out, int fmt,
 {
 	jas_image_fmtinfo_t *fmtinfo;
 	if (!(fmtinfo = jas_image_lookupfmtbyid(fmt))) {
+		jas_eprintf("format lookup failed\n");
 		return -1;
 	}
 	return (fmtinfo->ops.encode) ? (*fmtinfo->ops.encode)(image, out,
